@@ -1,5 +1,5 @@
 from .__about__ import __version__
-from .items import MenuItem
-from .menu import Menu
+from .menu import Menu, MenuItem
+
 
 __all__ = ['Menu', 'MenuItem']
